import type { Bot } from "../../bot.js";
import { Webhook } from "../../transformers/webhook.js";
/**
 * Edits a webhook.
 *
 * @param bot - The bot instance to use to make the request.
 * @param webhookId - The ID of the webhook to edit.
 * @returns An instance of the edited {@link Webhook}.
 *
 * @remarks
 * Requires the `MANAGE_WEBHOOKS` permission.
 *
 * Fires a _Webhooks Update_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/webhook#edit-webhook}
 */
export declare function editWebhook(bot: Bot, webhookId: bigint, options: ModifyWebhook): Promise<Webhook>;
export interface ModifyWebhook {
    /** The default name of the webhook */
    name?: string;
    /** Image for the default webhook avatar */
    avatar?: bigint | null;
    /** The new channel id this webhook should be moved to */
    channelId?: bigint;
    /** The reason you are modifying this webhook */
    reason?: string;
}
